@@ -1,14 +1,14 @@
+use v5.14;
+
 package Modulino::Demo3;
 use strict;
 use utf8;
 
-use v5.14.2;
-
 use warnings;
 
 require Modulino::Base;
 
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 =encoding utf8
 
@@ -141,7 +141,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2012-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2012-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the terms of the Artistic License 2.0.
 
