@@ -1,12 +1,12 @@
+use v5.14;
+
 package Modulino::Test;
 use strict;
 use utf8;
 
-use v5.14.2;
-
 use warnings;
 
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 UNITCHECK {
 sub _running_under_tester {
@@ -142,7 +142,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2013-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2013-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the terms of the Artistic License 2.0.
 
